#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hi-file-parser
version:              0.1.8.0
visibility:           public
id:                   hi-file-parser-0.1.8.0-8YK9c1yGtfeHgqD5G1MLgc
key:                  hi-file-parser-0.1.8.0-8YK9c1yGtfeHgqD5G1MLgc
license:              BSD-3-Clause
copyright:            Copyright 2015-2025, Stack contributors
maintainer:
    Michael Snoyman <michael@snoyman.com>,
    Mike Pilgrem <public@pilgrem.com>

author:               Hussein Ait-Lahcen <hussein.aitlahcen@gmail.com>
homepage:             https://github.com/commercialhaskell/hi-file-parser#readme
synopsis:             Parser for GHC'\''s *.hi files
description:
    A parser for GHC'\''s *.hi files. Extracts information about dependencies and
    usage of files.

category:             Development
abi:                  c5ae0e84f422768e5425ce48e177722d
exposed:              True
exposed-modules:      HiFileParser
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hi-file-parser-0.1.8.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hi-file-parser-0.1.8.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hi-file-parser-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hi-file-parser
hs-libraries:         HShi-file-parser-0.1.8.0-8YK9c1yGtfeHgqD5G1MLgc
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3 mtl-2.3.1
    rio-0.1.24.0-JkwqYIu0JXwGTNiCUtqCtk text-2.0.2
    vector-0.13.2.0-E81GJWrGuCo4SgJOIsfBQo

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

